"""
Kiegészító kijelző a számítógéphez

Az STM32F411CE blackpill mikrovezérlő kártyát CircuitPython 
nyelven programozzuk. A kártyához egy I2C interfésszel rendelkező
MCP23017 periféria bővítő csatlakozik, ami egy 16x2 alfanumerikus
LCD kijelzőt vezérel. A terminálkapcsolaton (USB virtuális soros port)
beérkező üzeneteket kiíratjuk az LCD kijelzőre.

A # karakter speciális jelentéssel bír: sortörést jelent
"""

import time
import board
import busio
import supervisor
from digitalio import *
from adafruit_mcp230xx.mcp23017 import MCP23017
import adafruit_character_lcd.character_lcd as characterlcd

# Initialize the I2C bus:
i2c = busio.I2C(board.SCL, board.SDA)
mcp = MCP23017(i2c, address=0x20, reset=True)    # MCP23017

# Modify this if you have a different sized character LCD
lcd_columns = 16
lcd_rows = 2

# LCD is connected to the GPIOB port of the MCP23017 IC:
lcd_rs = mcp.get_pin(8)    # B0
lcd_en = mcp.get_pin(9)    # B1
lcd_backlight = mcp.get_pin(10)   # B2
lcd_d4 = mcp.get_pin(12)   # B4
lcd_d5 = mcp.get_pin(13)   # B5
lcd_d6 = mcp.get_pin(14)   # B6
lcd_d7 = mcp.get_pin(15)   # B7

# Initialise the LCD class
lcd = characterlcd.Character_LCD_Mono(
    lcd_rs, lcd_en, lcd_d4, lcd_d5, lcd_d6, lcd_d7, lcd_columns, lcd_rows, lcd_backlight
)

text = "CircuitPython\nLCD display"
lcd.backlight = True               # Turn backlight on
lcd.clear()                        # Clear screen
lcd.message = text

# Main Loop
while True:
    if supervisor.runtime.serial_bytes_available:
        text = input().strip()
        if text != "":           
            # print("received: {}".format(text))
            lcd.clear()
            lcd.message = text.replace('#','\n')
